@@ -13,32 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 import horizon
 
-from openstack_dashboard.api import base
 from openstack_dashboard.dashboards.admin import dashboard
 
 
 class Ironic(horizon.Panel):
     name = _("Ironic Bare Metal Provisioning")
     slug = 'ironic'
-    permissions = ('openstack.roles.admin',)
-
-    def allowed(self, context):
-        request = context['request']
-        if not base.is_service_enabled(request, 'baremetal'):
-            return False
-        else:
-            return super(Ironic, self).allowed(context)
-
-    def nav(self, context):
-        request = context['request']
-        if not base.is_service_enabled(request, 'baremetal'):
-            return False
-        else:
-            return True
+    permissions = ('openstack.roles.admin', 'openstack.services.baremetal',)
 
 
 dashboard.Admin.register(Ironic)
